@@ -12,6 +12,7 @@ cart_collection: Collection = None
 site_collection: Collection = None
 checkout_collection: Collection = None
 order_collection: Collection = None
+counter_collection: Collection = None
 
 
 def set_collections(
@@ -25,6 +26,7 @@ def set_collections(
     site: Collection,
     checkout: Collection,
     order: Optional[Collection] = None,
+    counter: Optional[Collection] = None,
 ) -> None:
     global product_collection
     global coupon_collection
@@ -36,6 +38,7 @@ def set_collections(
     global site_collection
     global checkout_collection
     global order_collection
+    global counter_collection
     product_collection = product
     coupon_collection = coupon
     discount_collection = discount
@@ -46,6 +49,7 @@ def set_collections(
     site_collection = site
     checkout_collection = checkout
     order_collection = order
+    counter_collection = counter
 
 
 def get_collection(name: str) -> Collection:
@@ -69,6 +73,8 @@ def get_collection(name: str) -> Collection:
         return checkout_collection
     if name == "order":
         return order_collection
+    if name == "counter":
+        return counter_collection
 
 
 def get_site_config_doc() -> Union[Dict[str, Any], None]:
