@@ -7,12 +7,14 @@ from fastapi.requests import Request
 from fastapi.responses import HTMLResponse
 from requests import Response as ResponseType
 
+from fastel.cart.datastructures import OverseaSubtype
 from fastel.collections import get_collection, get_site_config
 from fastel.config import SdkConfig
 from fastel.exceptions import APIException
 from fastel.logistics.common.models import (
     LogisticsDataModel,
     LogisticsStatus,
+    LogisticsTrackStatusModel,
     LogisticTypes,
 )
 from fastel.logistics.ecpay.gateway import EcpayLogistics
@@ -105,7 +107,7 @@ class EcpayLogisticsCreate:
             name=sender_info["SenderName"], limit=10
         )
         data: EcpayLogisticsModel
-        if order.logistics_type == "HOME":
+        if order.logistics_type == LogisticTypes.HOME.value:
             data = EcpayLogisticsModel(
                 **common_props,
                 **sender_info,
@@ -113,7 +115,7 @@ class EcpayLogisticsCreate:
                 Distance=("00" if order.receiver_city == "台北市" else "01"),
                 Temperature="0001",
             )
-        elif order.logistics_type == "CVS":
+        elif order.logistics_type == LogisticTypes.CVS.value:
             data = EcpayLogisticsModel(
                 **common_props,
                 **sender_info,
@@ -124,6 +126,12 @@ class EcpayLogisticsCreate:
                 CollectionAmount=order.total if order.payment_subtype == "cod" else 0,
                 ReceiverStoreID=order.logistics_cvs_store_id,
             )
+        elif order.logistics_type == LogisticTypes.OVERSEA.value:
+            raise APIException(
+                status_code=400,
+                error="logistics_type_invalid",
+                detail="ecpay logistics type OVERSEA is invalid",
+            )
         else:
             raise APIException(
                 status_code=400,
@@ -193,7 +201,7 @@ class EcpayLogisticsCallback:
             self.response = "1|OK"
 
     def parse_payload(self, result: EcpayLogisticsCallbackModel) -> LogisticsDataModel:
-        if result.LogisticsType == "HOME":
+        if result.LogisticsType == LogisticTypes.HOME.value:
             home_status_table = {
                 "300": LogisticsStatus.pending,
                 "310": LogisticsStatus.pending,
@@ -378,7 +386,7 @@ class SFLogisticsCreate:
         validated = self.validate(order)
         parsed = self.parse_logistics(validated, extra_data)
         gateway_resp = self.gateway.create_logistics(parsed)
-        result = self.parse_gateway_resp(gateway_resp=gateway_resp)
+        result = self.parse_gateway_resp(gateway_resp=gateway_resp, order=validated)
         return result
 
     @staticmethod
@@ -413,10 +421,38 @@ class SFLogisticsCreate:
         sender_info: Dict[str, Any] = get_site_config(
             key="logistics_sender_info", default=default_sender_info
         )
+        counter = get_collection("counter").find_one_and_update(
+            {"collection": "logistics", "order_id": order.order_id},
+            {
+                "$inc": {"idx": 1},
+                "$setOnInsert": {"collection": "logistics", "order_id": order.order_id},
+            },
+            upsert=True,
+        )
+        if not counter:
+            counter = {"idx": 0}
+        if order.logistics_type == LogisticTypes.OVERSEA.value:
+            sender_cert_no = sender_info.get("SenderCertNo", "")
+            sender_cert_type = sender_info.get("SenderCertType", "001")
+            receiver_country = OverseaSubtype[order.logistics_subtype].value
+            receiver_post_code = extra_data.get("receiver_post_code", "")
+            receiver_region_first = extra_data.get("receiver_region_first", "")
+            receiver_region_second = extra_data.get("receiver_region_second", "")
+            receiver_region_third = extra_data.get("receiver_region_third", "")
+            receiver_address = extra_data.get("receiver_address", "")
+        else:
+            sender_cert_no = ""
+            sender_cert_type = ""
+            receiver_country = "TW"
+            receiver_post_code = order.receiver_zip
+            receiver_region_first = "台灣省"
+            receiver_region_second = order.receiver_city
+            receiver_region_third = order.receiver_district
+            receiver_address = order.receiver_address
         payload = {
             "customerCode": SdkConfig.sf_merchant_id,
             "orderOperateType": 1,
-            "customerOrderNo": order.order_id,
+            "customerOrderNo": f"{order.order_id}_{counter['idx']}",
             "interProductCode": extra_data.get("platform_code", "INT0005"),
             # 包裹數 *
             "parcelQuantity": extra_data.get("parcel_quantity", 1),
@@ -457,22 +493,24 @@ class SFLogisticsCreate:
                 "email": sender_info.get("SenderEmail", ""),
                 "cargoType": extra_data.get("cargo_type", 1),
                 "telNo": sender_info.get("SenderPhone", ""),
+                "certType": sender_cert_type,
+                "certCardNo": sender_cert_no,
             },
             # 收件人訊息
             "receiverInfo": {
                 # 寄件人名字
                 "contact": order.receiver_name,
                 # 寄件國家/地區
-                "country": "TW",
+                "country": receiver_country,
                 # 郵編
-                "postCode": order.receiver_zip,
+                "postCode": receiver_post_code,
                 # 州/省
-                "regionFirst": "台灣省",
+                "regionFirst": receiver_region_first,
                 # 城市
-                "regionSecond": order.receiver_city,
+                "regionSecond": receiver_region_second,
                 # 區
-                "regionThird": order.receiver_district,
-                "address": order.receiver_address,
+                "regionThird": receiver_region_third,
+                "address": receiver_address,
                 "email": order.receiver_email,
                 "cargoType": extra_data.get("cargo_type", 1),
                 "phoneNo": order.receiver_phone,
@@ -484,12 +522,14 @@ class SFLogisticsCreate:
         return SFLogisticsModel.validate(payload)
 
     @staticmethod
-    def parse_gateway_resp(gateway_resp: Dict[str, Any]) -> LogisticsDataModel:
+    def parse_gateway_resp(
+        gateway_resp: Dict[str, Any], order: Order
+    ) -> LogisticsDataModel:
         resp_data = gateway_resp.get("data", {})
         if gateway_resp.get("success", False):
             logistics_id = resp_data.get("sfWaybillNo", "")
             logistics_status = LogisticsStatus.pending
-            logistics_message = "訂單處理中(已收到訂單資料)"
+            logistics_message = "已收到訂單資料"
 
         else:
             logistics_id = ""
@@ -500,7 +540,8 @@ class SFLogisticsCreate:
             provider="sf",
             order_id=resp_data.get("customerOrderNo", ""),
             logistics_id=logistics_id,
-            logistics_type="UNKNOW",
+            logistics_type=order.logistics_type,
+            logistics_subtype=order.logistics_subtype,
             logistics_status=logistics_status,
             logistics_message=logistics_message,
         )
@@ -516,7 +557,7 @@ class SFLogisticsStatus:
             stage=SdkConfig.stage,
         )
 
-    def __call__(self, logistics_id: str) -> LogisticsDataModel:
+    def __call__(self, logistics_id: str) -> LogisticsTrackStatusModel:
         parsed = self.parse_data(logistics_id)
         gateway_resp = self.gateway.query_track(parsed)
         result = self.parse_gateway_resp(gateway_resp=gateway_resp)
@@ -528,25 +569,34 @@ class SFLogisticsStatus:
         return data
 
     @staticmethod
-    def parse_gateway_resp(gateway_resp: Dict[str, Any]) -> LogisticsDataModel:
-        resp_data = gateway_resp.get("data", {})
+    def parse_gateway_resp(gateway_resp: Dict[str, Any]) -> LogisticsTrackStatusModel:
+        resp_data = gateway_resp.get("data", [])
+        if resp_data:
+            tracking_data = resp_data[-1]
+        else:
+            tracking_data = {}
         if gateway_resp.get("success", False):
-            track_data: Dict[str, Any] = resp_data.get("tackDetailItems", [])[0]
-            logistics_id = resp_data.get("sfWaybillNo", "")
-            logistics_status = LogisticsStatus.pending
-            logistics_message = track_data.get("trackOutRemark", "")
+            track_details: List[Dict[str, Any]] = tracking_data.get(
+                "trackDetailItems", []
+            )
+            logistics_id = tracking_data.get("sfWaybillNo", "")
+            logistics_message = ""
+            if track_details:
+                for detail in track_details:
+                    logistics_message += detail.get("trackOutRemark", "") + ";"
+            else:
+                logistics_message = tracking_data.get("trackSummary", "")
 
         else:
-            logistics_id = resp_data.get("sfWaybillNo", "")
-            logistics_status = LogisticsStatus.exception
+            logistics_id = tracking_data.get("sfWaybillNo", "")
             logistics_message = gateway_resp.get("msg", "")
 
-        return LogisticsDataModel(
+        return LogisticsTrackStatusModel(
             provider="sf",
-            order_id="",
+            tracking_type="string",
             logistics_id=logistics_id,
-            logistics_status=logistics_status,
             logistics_message=logistics_message,
+            logistics_detail=gateway_resp,
         )
 
 
