@@ -12,10 +12,14 @@ def log_all(action: str) -> WrapT:
     def inner(fn: FuncT) -> FuncT:
         @wraps(fn)
         def wrapper(*args: Any, **kwargs: Any) -> Any:
-            url: str = args[0]
+            try:
+                url: str = args[0]
+            except IndexError:
+                url = kwargs["url"]
+
             json = kwargs.get("json", None)
             data = kwargs.get("data", None)
-            print("[REQ]", action, url, f"json={json}", f"data={data}")
+            print("[REQ]", action, f"url={url}", f"json={json}", f"data={data}")
             return fn(*args, **kwargs)
 
         return cast(FuncT, wrapper)
